@@ -18,6 +18,36 @@ usb_device() {
 # Parse /proc/cmdline for boot options.
 echo "Checking for SliTaz cmdline options..."
 
+# Default user account without password (uid=1000). In live mode the option
+# user=name can be used, but user must be added before home= to have home dir.
+# This option is not handled by a loop and case like others and has no
+# effect on an installed system.
+if ! grep -q "100[0-9]:100" /etc/passwd; then
+	if fgrep -q "user=" /proc/cmdline; then
+		USER=$(cat /proc/cmdline | sed 's/.*user=\([^ ]*\).*/\1/')
+		# Avoid usage of an existing system user or root.
+		if grep -q ^$USER /etc/passwd; then
+			USER=tux
+		fi
+	else
+		USER=tux
+	fi
+	echo -n "Configuring user and group: $USER..."
+	adduser -D -s /bin/sh -g "SliTaz User" -G users -h /home/$USER $USER
+	passwd -d $USER >/dev/null
+	status
+	# Audio and cdrom group.
+	addgroup $USER audio
+	addgroup $USER cdrom
+	addgroup $USER video
+	addgroup $USER tty
+	# Slim default user.
+	if [ -f /etc/slim.conf ]; then
+		sed -i s/"default_user .*"/"default_user        $USER"/\
+			/etc/slim.conf
+	fi
+fi
+
 for opt in $(cat /proc/cmdline)
 do
 	case $opt in
@@ -61,11 +91,11 @@ do
 			if [ -n "$DEVID" ] && fgrep -q "$DEVID" /proc/partitions ; then
 				echo "Mounting /home on /dev/$DEVID... "
 				[ -d /home/$USER ] && mv /home/$USER /tmp/$USER-files
-				mount /dev/$DEVID /home -o uid=1000,gid=100 2>/dev/null \
-					|| mount /dev/$DEVID /home
+				mount /dev/$DEVID /home &&
 				case "$(/sbin/blkid | grep /dev/$DEVID:)" in
-				*\"ntfs\"*|*\"vfat\"*) mount.posixovl /home ;;
+				*\"ntfs\"*|*\"vfat\"*) mount.posixovl -F /home ;;
 				esac
+				mount /home -o remount,uid=1000,gid=100 2>/dev/null
 				# Check if swap file must be generated in /home: swap=size (Mb).
 				# This option is only used within home=device.
 				if grep -q "swap=[1-9]*" /proc/cmdline; then
@@ -151,36 +181,6 @@ do
 	esac
 done
 
-# Default user account without password (uid=1000). In live mode the option
-# user=name can be used, but user must be added before home= to have home dir.
-# This option is not handled by a loop and case like others and has no
-# effect on an installed system.
-if ! grep -q "100[0-9]:100[0-9]" /etc/passwd; then
-	if fgrep -q "user=" /proc/cmdline; then
-		USER=$(cat /proc/cmdline | sed 's/.*user=\([^ ]*\).*/\1/')
-		# Avoid usage of an existing system user or root.
-		if grep -q ^$USER /etc/passwd; then
-			USER=tux
-		fi
-	else
-		USER=tux
-	fi
-	echo -n "Configuring user and group: $USER..."
-	adduser -D -s /bin/sh -g "SliTaz User" -G users -h /home/$USER $USER
-	passwd -d $USER >/dev/null
-	status
-	# Audio and cdrom group.
-	addgroup $USER audio
-	addgroup $USER cdrom
-	addgroup $USER video
-	addgroup $USER tty
-	# Slim default user.
-	if [ -f /etc/slim.conf ]; then
-		sed -i s/"default_user .*"/"default_user        $USER"/\
-			/etc/slim.conf
-	fi
-fi
-
 # If no default WM fallback to Openbox (we never know).
 if [ ! -f /etc/X11/wm.default ]; then
 	echo "openbox" > /etc/X11/wm.default
